==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebDocumentHostDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSplitPaneDescriptionMetadata } from "./WebSplitPaneDescriptionMetadata";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebDocumentHostDescription } from "./WebDocumentHostDescription";
/**
 * @hidden
 */
export let WebDocumentHostDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDocumentHostDescriptionMetadata extends Base {
        static b(a) {
            if (WebDocumentHostDescriptionMetadata.a == null) {
                WebDocumentHostDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDocumentHostDescriptionMetadata.c(WebDocumentHostDescriptionMetadata.a);
            }
            if (a.k(WebDocumentHostDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebDocumentHostDescriptionMetadata.a);
            WebSplitPaneDescriptionMetadata.d(a);
        }
        static c(a) {
            WebDockManagerPaneDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:DocumentHost");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("Id", "String");
            a.item("PaneType", "(wc:Type)ExportedType:string:DockManagerPaneType");
            a.item("PaneType@names", "SplitPane;ContentPane;TabGroupPane;DocumentHost");
            a.item("RootPane", "ExportedType:WebSplitPane");
            a.item("Size", "Number:double");
            WebDocumentHostDescriptionMetadata.e(a);
        }
        static d(a) {
            WebDocumentHostDescriptionMetadata.b(a);
            a.ad("WebDocumentHost", () => new WebDocumentHostDescription());
            a.ac("WebDocumentHost", WebDocumentHostDescriptionMetadata.a);
        }
        static e(a) {
            a.item("__preferUnsuffixed", "Boolean");
        }
    }
    WebDocumentHostDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDocumentHostDescriptionMetadata, 'WebDocumentHostDescriptionMetadata');
    WebDocumentHostDescriptionMetadata.a = null;
    return WebDocumentHostDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebDocumentHostDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSplitPaneDescriptionMetadata } from "./WebSplitPaneDescriptionMetadata";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebDocumentHostDescription } from "./WebDocumentHostDescription";
/**
 * @hidden
 */
export let WebDocumentHostDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDocumentHostDescriptionMetadata extends Base {
        static b(a) {
            if (WebDocumentHostDescriptionMetadata.a == null) {
                WebDocumentHostDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDocumentHostDescriptionMetadata.c(WebDocumentHostDescriptionMetadata.a);
            }
            if (a.k(WebDocumentHostDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebDocumentHostDescriptionMetadata.a);
            WebSplitPaneDescriptionMetadata.d(a);
        }
        static c(a) {
            WebDockManagerPaneDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:DocumentHost");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Id", "String");
            a.item("PaneType", "(wc:Type)ExportedType:string:DockManagerPaneType");
            a.item("PaneType@names", "SplitPane;ContentPane;TabGroupPane;DocumentHost");
            a.item("RootPane", "ExportedType:WebSplitPane");
            a.item("Size", "Number:double");
            WebDocumentHostDescriptionMetadata.e(a);
        }
        static d(a) {
            WebDocumentHostDescriptionMetadata.b(a);
            a.ae("WebDocumentHost", () => new WebDocumentHostDescription());
            a.ad("WebDocumentHost", WebDocumentHostDescriptionMetadata.a);
        }
        static e(a) {
            a.item("__preferUnsuffixed", "Boolean");
        }
    }
    WebDocumentHostDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDocumentHostDescriptionMetadata, 'WebDocumentHostDescriptionMetadata');
    WebDocumentHostDescriptionMetadata.a = null;
    return WebDocumentHostDescriptionMetadata;
})();
